# __Start Homework 1 ####
#............................
# Births 2012 Analysis for EPID 799C: PNC decrease PT birth? ####
# Mike Dolan Fliss, August 2017
# Aim: Does early prenatal care (<month 5) decrease the risk of preterm (<week 37) birth?
# (This Descriptive header is HW1.Q1a)
#............................ (<- example of HW1.Q1b, comment bar)
# Project Notes:
# Birth Certificate Revisions: https://www.cdc.gov/nchs/nvss/vital_certificate_revisions.htm (HW1.Q1d, clickable link)
#............................

#............................
# Libraries, directories, load data (HW1.Q1f) ####
#............................
# NOTE: May need to install these packages in advance on your local machine.
# install.packages("tableone")
library(tidyverse) # for ggplot, dplyr in HW1-4 (<- example of a post-line code comment, HW1.Q1c)
library(lubridate) # for dates in HW2
library(tableone) # used in HW2
# Set directories.
# Mike's home dir: setwd("D:/User/Dropbox (Personal)/Education/Classes/18Fall_EPID799C_RforEpi/")
data_dir = paste0(getwd(), "/data")
output_dir = paste0(getwd(), "/data/output")
map_dir = paste0(data_dir, "/data/maps") # used later
# Note you'll need to set different ones with setwd()! Since we're building this as a github repo the wd defaults to script dir.
# More on git here: http://r-bio.github.io/intro-git-rstudio/ . There's also a datacamp on it.
#............................

#............................
# Read data (HW1.Q2) ####
#............................
births = read.csv("data/births2012.csv", stringsAsFactors = F) # (HW1.Q2a)
head(births) # (HW1.Q2b)
#births = read.csv("births2012_small.csv", stringsAsFactors = F) #start with small version

names(births) = tolower(names(births)) #drop names to lowercase
#..................................................
# (HW1.Q3) Notice all these nice blocks?  I like to
# have a header at the top, and block comments at the bottom.
#..................................................


# ......................................
# Exploring Data - (HW1Q3 & HW1Q4) ####
# ......................................
dim(births) # (HW1.Q3b)
summary(births[,c("wksgest", "mdif")]) # (HW1.Q3c)
str(births[,c("mage", "wksgest", "mdif")]) # (HW1.Q3d)
class(births$mage); class(births$wksgest); class(births$mdif)
str(births$mage); str(births$wksgest); str(births$mdif)

## (HW1.Q4)
births_sample = births[1:1000, c("mage", "mdif", "visits", "wksgest", "mrace")] #A
plot(births_sample) #B

#C
births_sample = births[sample(nrow(births), 1000), c("mage", "mdif", "visits", "wksgest", "mrace")] #C
car::scatterplotMatrix(births_sample)
GGally::ggpairs(births_sample) # later I'll demo how to use color here after some recoding.
# ......................................


# ......................................
# Recode Variables: Exposure, Outcome & Covariates (HW1.Q5) ####
# ......................................
## (HW1.Q5)
### A. Prenatal Care (Exposure)
#### i
table(births$mdif, useNA = "always")

#### ii
# See data dictionary, but 88 means no early prenatal care and 99 means missing

#### iii
births$mdif[births$mdif==99] <- NA

#### iv
boxplot(births$mdif[births$mdif != 88], main="Month Prenatal Care Began, \n Excluding Unkowns and No Prenatal Care")

#### v
births$pnc5 <- ifelse(births$mdif <= 5, 1, 0)

#### vi
births$pnc5_f <- factor(births$pnc5, levels=c(0,1), labels=c("No Early PNC", "Early PNC"))

#### vii
table(births$mdif, births$pnc5_f, useNA = "always")


# (HW1.Q5 continued)
### B. Preterm Birth (Outcome)
#### i
hist(births$wksgest) #quick look
#### ii
births$preterm <- ifelse(births$wksgest >= 20 &births$wksgest < 37, 1,
                         ifelse(births$wksgest >= 37 & births$wksgest < 99, 0, NA)
)

#### iii
births$preterm_f <- factor(births$preterm, levels=c(0,1), labels=c("term", "preterm"))

#### iv
births$preterm_f <- cut(births$wksgest, breaks = c(0,36,99), labels =  c("preterm", "term"))

# (HW1.Q5 continued)
### C. Plurality (covariate)
#### i
table(births$plur, useNA = "always") # looks fine, no 9 values for unknown

# (HW1.Q5 continued)
### D. Maternal Age (covariate)
#### i
table(births$mage, useNA = "always")

#### ii
# See data dictionary, but 99 means misssing

#### iii
births$mage[births$mage==99] <- NA

#### iv
par(mfrow=c(1,2)) # make our plot window 2 columns
boxplot(births$mage, main="Boxplot of Maternal Age Distribution")
plot(density(births$mage), main="Density Plot of Maternal Age Distribution")
par(mfrow=c(1,1)) # always always reset after this!

#### v
births$mage_centered <- births$mage - mean(births$mage, na.rm = T)
hist(births$mage) # looks to be expected
summary(births$mage)

# (HW1.Q5 continued)
### E. Cigarette Use (covariate)
#### i
table(births$cigdur, useNA = "always") # check to see what values are in cigdur
births$cigdur <- ifelse(births$cigdur == "Y", 1,
                        ifelse(births$cigdur == "N", 0, NA)) # NA for when case is U - i.e. unknown

#### ii
births$smoker_f <- factor(births$cigdur, levels=c(0,1), labels=c("Non-smoker", "Smoker"))

#### ii
table(births$cigdur, births$smoker_f, useNA = "always")


# (HW1.Q5 continued)
### F. Date of Birth (covariate)
#### i
# https://github.com/tidyverse/lubridate
#### ii
?lubridate
vignette("lubridate")

#### iii
library(lubridate) # normally this would go at the top of the script under a packages chunk

#### iv
births$dob_d <- lubridate::ymd(births$dob)

# (HW1.Q5 continued)
### G. Sex (covariate)
#### i
table(births$sex, useNA = "always") # check what initial values are
births$sex[births$sex==9] <- NA
births$sex_f <- factor(births$sex, levels=c(1,2), labels=c("Male", "Female"))
table(births$sex_f, births$sex, useNA="always")

# (HW1.Q5 continued)
### G. Maternal Race/Ethnicity (covariate)
#### i
table(births$mrace, births$methnic, useNA = "always") # check what initial values are

## ii
mergedf <- data.frame(
  mrace = c(sort(rep(seq(1,4),3))),
  methnic = as.character(rep(c("Y", "N", "U"), 4)),
  raceeth_f =factor(c("White Hispanic", "White non-Hispanic", "Other",
                      rep("African American", 3),
                      rep("American Indian or Alaska Native", 3),
                      rep("Other", 3)
  )
  ),
  stringsAsFactors = F)

births <- merge(x=births, y=mergedf, by=c("mrace", "methnic"))

#### iii
table(births$mrace, births$methnic, births$raceeth_f, useNA = "always") # looks good
# ......................................

# ......................................
# Optional data exploration (HW1.Q6) ####
# ......................................

# (HW1.Q6)
## A
CreateTableOne(vars = c("mage", "pnc5_f", "smoker_f", "sex_f"),
               strata = c("preterm_f"),
               data = births)

## B
mice::md.pattern(births)

## C
GGally::ggpairs(data = births[1:1000, c("pnc5_f", "preterm_f")],
                title="Exposure versue Outcome for First 1,000 Obserations")
# ......................................

# ......................................
# __End Homework 1 /  Start Homework 2 ####
# ......................................


# ......................................
# Eligibility criteria & core recoding  (HW2 part 1) ####
# ......................................
# Create many inclusion variables, all of which have to be =1 to be included.
births$weeknum = week(births$dob_d) #thanks, lubridate! (HW2.1.Q1)
# a. Has gestation data (weeks), and at least 20 weeks gestation pre-birth (weeks >= 20)
births$incl_hasgest = as.numeric(!is.na(births$wksgest)) #(HW2.1.Q2a)
births$incl_enoughgest = as.numeric(births$wksgest >= 20) #(HW2.1.Q2b)
# b. Less than 20 weeks gestation before Jan 1 of year (LMP > Aug 20), or weeks-weeknum>=19, w/ weeknum=1 for Jan 1-7
births$incl_lateenough = as.numeric(births$wksgest - births$weeknum <= 19) #(HW2.1.Q2c)
# c. Start date of gestation was 45 (max gest in'11) w prior to Jan 1 of next year, so all births are observed in year
births$incl_earlyenough = as.numeric(births$weeknum - births$wksgest <=7) #(HW2.1.Q2d)
# d. singletons only
births$incl_singleton = as.numeric(births$plur == 1) #(HW2.Q2e)
# births$incl_hasnumdata = as.numeric(births$plur != 9) #not bothering to recode is ok. Isn't this one redundant with above?
# e. no congential anomalies - Let's use apply for efficiency
congen_anom = c("anen","mnsb","cchd", "cdh", "omph","gast", "limb", "cl","cp","dowt","cdit", "hypo") #(HW2.1.Q3a)
# below is just a useful aside to check that there is No "U" (i.e. none missing) before running the code to make the new variable
births$incl_hasanomdata = as.numeric(apply(births[,congen_anom]!="U", FUN=all, 1)) #All not missing = not any missing
births$incl_noanomalies = as.numeric(apply(births[,congen_anom]=="N", FUN=all, 1)) #All not present #(HW2.1.Q3b)

# Below is the example grepl (HW2.1.Q4b)
grepl("a", c("banana", "peach", "ornge"))
eligibility_drops = nrow(births) - apply(births[,grepl("incl_", names(births))], FUN=sum, MARGIN = 2, na.rm=T) #(HW2.1.Q4c optional)
eligibility_drops #(HW2.1.Q4c optional)

births$include_allpass = apply(births[, grepl("incl_", names(births))], FUN=all, MARGIN = 1) #(HW2.1.Q4d indicator for the inclusion criteria yes/no)
old_births <- births #(HW2.1.Q4a)

births = births[births$include_allpass, ] #(HW2.1.Q4e now apply the inclusion criteria to subset your births data set)
# to see what warnings are being thrown you can type warnings() -- below:
warnings() # Just letting me know I'm casting those 1s as TRUEs. That's ok.

dim(old_births) #(HW2.1.Q4f)
dim(births) #(HW2.1.Q4f)

#(HW2.1.Q5 Optional Challenge)
# Results of exclusion
cat("Leaving eligibility checks with n =", formatC(nrow(births), big.mark = ","),
    "births of original", formatC(nrow(old_births), big.mark = ",")) #(HW2.1.Q4d)
names(births)
vars_of_interest = c("pnc5_f", "preterm_f", "smoker_f", "wksgest", "sex", "meduc", "mage", "raceeth_f", "weeknum", "include_allpass")
tableone::CreateTableOne(data=births[, vars_of_interest]) #(HW2.1.Q5)
tableone::CreateTableOne(data=old_births[, vars_of_interest], strata="include_allpass")

# Save a smaller version for future loading
vars_to_save = c(vars_of_interest, "cores", "kotel")
births_sm = births[, vars_to_save]
save("births_sm", file = "births_sm.rdata")
# ......................................
# Finishes with 62,370 of 122,513 ####
# ......................................

# ......................................
# __End Homework 2 /  Start Homework 3 ####
# ......................................

# ......................................
# Explore data (HW3 part 1) ####
# ......................................
#(HW2.2.Q6A) Graph weeks
npop = formatC(sum(!is.na(births$wksgest)), big.mark=',') #(HW2.2.Q6a)
ggplot(data=births, aes(x=wksgest, y=..prop..))+geom_bar() + #Does what you need, as does geom_histogram()
  labs(title="Figure 1: Proportional distribution of gestational age at birth",
       subtitle=paste0("From ", npop, " births in NC in 2012 from the NC SCHS, posted at Odum Institute"),
       x="Weeks of gestation", y="Proportion of population") +
  theme_bw()

#A2.1 : Working with weeknum. - should double check this. Just used %V above.
hist(births$weeknum, breaks = min(births$weeknum):max(births$weeknum)) # Looks weird


  #(HW3.1.Q1a): Working with weeknum. - should double check this. Just used %V above.
  hist(births$weeknum, breaks = min(births$weeknum):max(births$weeknum)) # Looks weird

#(HW3.1.Q1B) : Graph weeknum
ggplot(births, aes(x=weeknum, y=..prop..)) + geom_bar() +
  labs(title="Throwaway: Investigating Weeknum",
       subtitle="Note to self : Weeknum needs some work, doesn't quite match SAS",
       x="Week number of birth", y="Proportion of population") +
  theme_bw()

#(HW3.1.Q1C) weeks vs. weeknum
ggplot(births, aes(x=wksgest, y=weeknum)) +
  geom_jitter(width=1, height=1, pch=".", alpha=0.3)+
  labs(title="Throwaway: week vs. weeknum",
       subtitle="Note to self: Does this match what we expect given the inclusion criteria?",
       x="weeks of gestation", y="week number of birth in year")+
  theme_bw()


#(HW3.1.Q1D)
# Note here that you can ggplot objects that are "appendable"
# which is to say you can add on new features by adding on LAYERS
plotObj <- ggplot(births, aes(x=wksgest, y=weeknum)) +
  geom_jitter(width=1, height=1, pch=".", alpha=0.3)+
  labs(title="Throwaway: week vs. weeknum",
       subtitle="Note to self: Does this match what we expect given the inclusion criteria?",
       x="weeks of gestation", y="week number of birth in year")+
  theme_bw()
plot(plotObj)
## append new feature
plotObj + geom_bin2d(binwidth=1, alpha=0.8)





#(HW3.1.Q1E)
require("ggridges")
ggplot() +
  geom_density_ridges_gradient(data=births, aes(x=mage, y=factor(cut(wksgest, 10)), fill=..x..)) +
  scale_fill_gradientn(colors=c("#fc8d59", "#ffffbf", "#91cf60")) +
  facet_grid(meduc~raceeth_f) +
  ggtitle("Distribution of Weeks Gestation by Birth Outcome") +
  labs(subtitle="This is the continuous variable we dichotomized") +
  ylab("Weeks of Gestations factorized") + xlab("mage") +
  theme_bw()

# ......................................
# Functional Form of maternal age w/ dplyr and ggplot2 #(HW3 part 1) ####
# ......................................

mage_df = births %>% group_by(mage) %>% #(HW3.2.2) setup
  summarize(n=n(),
            pct_earlyPNC = mean(pnc5, na.rm=T),
            pct_preterm = mean(preterm, na.rm=T))
head(mage_df) #(HW3.2.2) answer

#(HW3.2.3A)
ggplot(mage_df, aes(mage, pct_preterm))+
  geom_point(aes(size=n))+
  geom_smooth(aes(weight=n), color="blue", method="loess")+
  labs(title="% Preterm vs. Maternal Age",
       x="maternal age", y="% preterm",
       subtitle="Investigating function form of maternal age",
       caption="Note for future glms: Seems quadratic. Blue is loess, red is square linear.")

#(HW3.2.3B)  Optional Challenge
ggplot(mage_df, aes(mage, pct_preterm)) +
  geom_point(aes(size=n)) +
  geom_smooth(aes(weight=n), color="blue") +
  geom_smooth(aes(weight=n), method="lm", formula=y ~ poly(x, 2), color="red", lty=2) + # this is the square error term
  labs(title="% Preterm vs. Maternal Age",
       x="maternal age", y="% preterm",
       subtitle="Investigating function form of maternal age",
       caption="Note for future glms: Seems quadratic. Blue is loess, red is square linear.")

# In the future, let's add some splines (e.g. restricted cubic)
# ......................................


# ......................................
# HW3.3: County stories ####
# ......................................

# ......................................
# County specific stories w/ dplyr and ggplot2
# ......................................
#(HW3.3.4A)
format_helper = read.csv("data/birth-format-helper-2012.csv", stringsAsFactors = F)
#(HW3.3.4A.i)
county_data = format_helper[format_helper$variable == "cores",] #base R way
#(HW3.3.4A.ii)
names(county_data) = c("variable", "cores", "county_name", "FIPS")
#(HW3.3.4A.iii)
county_data$var = NULL #drop in base R. There are other ways...
#(HW3.3.4A.iv)
county_data$cores = as.numeric(county_data$cores)
str(county_data$cores)

#(HW3.3.4B) same results as above but now using "tidy" methods and more human readable
county_data = format_helper %>%
  filter(variable == "cores") %>%
  rename(cores=code, county_name=recode, FIPS=helper) %>%
  select(-variable) %>%
  mutate(cores = as.numeric(cores))

#(HW3.3.4C)
# Load tier data
# https://www.nccommerce.com/research-publications/incentive-reports/county-tier-designations
county_tiers = read.csv("data/county_tiers.csv", stringsAsFactors = F) # shell.exec("county_tiers.csv")
#(HW3.3.4C.i)
str(county_tiers$econ_tier)
#(HW3.2.4C.ii)
county_tiers$econ_tier = ordered(county_tiers$econ_tier)

#(HW3.3.4D)
county_df = births %>% group_by(cores) %>%
  summarize(n=n(),
            pct_earlyPNC = mean(pnc5, na.rm=T),
            pct_preterm = mean(preterm, na.rm=T)) %>%
  left_join(county_data) %>%
  left_join(county_tiers)
head(county_df) #(HW3.2.3D) output


#(HW3.2.4E) write this out to your local directory
write.csv(x=county_df, "data/county_birth_summary.csv", row.names = F, quote = F)


#(HW3.2.5)
# Create a plot with ggplot
plotObj <- ggplot(county_df, aes(x=pct_earlyPNC, y=pct_preterm, color=econ_tier))+
  geom_point(aes(size=n))+geom_text(aes(label=county_name), nudge_y=.01, alpha=0.5)+
  geom_smooth(se=F)
plot(plotObj)
#(HW3.2.5a)
plotly::ggplotly(plotObj)

#(HW3.2.6A)
county_name_ord = factor(county_df$county_name, county_df$county_name[order(county_df$pct_earlyPNC)], ordered=T)

#(HW3.3.6B)
county_df <- county_df %>%
  mutate(county_name_ord = county_name_ord) %>%
  gather(key=variable, value=value, n, pct_earlyPNC, pct_preterm) %>%
  head()
#(HW3.3.6C)
county_df %>%
ggplot(aes(county_name_ord, value, fill=econ_tier)) +
  geom_col() +
  coord_flip() +
  facet_wrap(~variable, scales = "free_x")

# ......................................
# __End Homework 3 /  Start Homework 4 ####
# ......................................
# ......................................
# Summary Tables (HW4 part 1)
# ......................................
# Crude effects #HW4.Q1
table(births$pnc5_f, births$preterm_f)
prop.table(table(births$pnc5_f, births$preterm_f), margin = 1) #risks
pt = prop.table(table(births$pnc5_f, births$preterm_f), margin = 1)
pt[2,1]-pt[1,1] #(HW4.1.1A)
pt[2,1]/pt[1,1] #(HW4.1.1B)
(pt[2,1]/pt[1,1])/(pt[2,2]/pt[1,2]) #(HW4.1.1C)
# For tabular effects, see epi2by2 and epitools packages... or not. It is very "particular"


#(HW4.1.2)
pt2 = prop.table(table(births$pnc5_f, births$preterm_f, births$raceeth_f),
                 margin = c(1,3))

# ggplot #HW4.1.Q3
pt2_df = data.frame(pt2); names(pt2_df) = c("exposure", "outcome", "group", "estimate")
ggplot(data=pt2_df[pt2_df$outcome == "preterm",],
       aes(x=exposure, y=estimate, color=group, group=group))+
  geom_point()+geom_path()+geom_hline(yintercept=0.125)+
  annotate("text", x=.7, y=.13, label="EMM note line")+
  labs(title="Quick look at Crude EMM of RD by Race-Ethnicity", x= "Prevalence of Preterm Birth",
       subtitle="Note possible EMM in the angle of the lines... \n ...and disparities more impactful than our intervention. ")

#RD model # HW4.2.Q4
m_crude_rd = glm(data=births, preterm_f ~ pnc5_f, family=binomial(link="identity"))

# factor referrent matters! #HW4.2.Q5
# births$preterm_f = relevel(births$preterm_f, ref = "preterm")
levels(births$preterm_f) # If levels are backwards you'll need something like the below line:
births$preterm_f = relevel(births$preterm_f, ref = "term")
m_crude_rd = glm(data=births, preterm_f ~ pnc5_f, family=binomial(link="identity"))

# Model object structure HW4.2.Q6
str(m_crude_rd)
str(m_crude_rd, max.level = 1)
# It's a list with a buncha stuff in it!

# HW4.2.Q7
coef(m_crude_rd)
confint(m_crude_rd)

# HW4.2.Q8
m_crude_results = data.frame(model="M1: Crude", cbind(broom::tidy(m_crude_rd), confint(m_crude_rd)), stringsAsFactors = F)[2,]
broom::confint_tidy(m_crude_rd)
broom::confint_tidy(m_crude_rd)


# HW4.2.Q9
births$mage_sq = births$mage^2 # Can also use I(), or poly() or polym(), but be mindful...
model_vars = c("pnc5_f", "preterm_f", "raceeth_f", "smoker_f", "mage", "mage_sq") #in consideration from DAG
model_data = births[,model_vars]

m_plussmoke_rd = glm(data=births, preterm_f ~ pnc5_f + smoker_f, family=binomial(link="identity"))
model_results = rbind(m_crude_results, data.frame(model="M2: M1+smoking", cbind(broom::tidy(m_plussmoke_rd), confint(m_plussmoke_rd)), stringsAsFactors = F)[2,])

m_plusmage_rd = glm(data=births, preterm_f ~ pnc5_f + smoker_f + mage, family=binomial(link="identity"))
model_results = rbind(model_results, data.frame(model="M3: M2+mage", cbind(broom::tidy(m_plusmage_rd), confint(m_plusmage_rd)), stringsAsFactors = F)[2,])

m_plusmagesq_rd = glm(data=births, preterm_f ~ pnc5_f + smoker_f + mage + mage_sq, family=binomial(link="identity"))
model_results = rbind(model_results, data.frame(model="M4: M3+mage_sq", cbind(broom::tidy(m_plusmagesq_rd), confint(m_plusmagesq_rd)), stringsAsFactors = F)[2,])

m1_df = c(coef(m1)[2], confint(m1)[2,], std.error = m1_summary$coefficients[2,2])
m2_df = c(coef(m2)[2], confint(m2)[2,], std.error = summary(m2)$coefficients[2,2])
m3_df = c(coef(m3)[2], confint(m3)[2,], std.error = summary(m3)$coefficients[2,2])
m4_df = c(coef(m4)[2], confint(m4)[2,], std.error = summary(m4)$coefficients[2,2])

results_df = data.frame(rbind(m1_df, m2_df, m3_df, m4_df))
results_df$model_name = row.names(results_df)

# method 1: dplyr & broom
library(broom)
m1_df = bind_cols(tidy(m1), confint_tidy(m1)) %>% filter(term == "pnc5_fEarly PNC") %>% mutate(model_name="M1: Crude")
m2_df = bind_cols(tidy(m2), confint_tidy(m2)) %>% filter(term == "pnc5_fEarly PNC") %>% mutate(model_name="M2: M1 + smoking")
m3_df = bind_cols(tidy(m3), confint_tidy(m3)) %>% filter(term == "pnc5_fEarly PNC") %>% mutate(model_name="M3: M2 + mage")
m4_df = bind_cols(tidy(m4), confint_tidy(m4)) %>% filter(term == "pnc5_fEarly PNC") %>% mutate(model_name="M4: M3 + mage^2")
#....
results_df = bind_rows(m1_df, m2_df, m3_df, m4_df)
results_df

# method 2: dplyr & purrr
model_results = function(m){bind_cols(tidy(m), confint_tidy(m)) %>% filter(term == "pnc5_fEarly PNC")}
model_results(m1)

model_df = tibble(models = list(m1, m2, m3, m4),
                  model_name = paste0("M", 1:4),
                  results = map(models, model_results),
                  estimate = map_dbl(results, "estimate"))
model_df
# ^ The estimate variable is just a demo of the list accessor

results_df = bind_rows(model_df$results) %>%
  mutate(model_name = model_df$model_name)
results_df

# method 3.... fancier purrr!
vars = c("preterm_f", "pnc5_f", "smoker_f", "mage", "mage_sq") # predictors
model_maker = function(v) { glm(preterm_f ~ ., family=binomial("identity"), data=births_sm[,v]) }
model_df = tibble(covariates = map(2:length(vars), ~ vars[1:.]), models = map(covariates, model_maker))
#....

# plotting
ggplot(results_df, aes(model_name, estimate, color=std.error, fill=std.error))+
  geom_linerange(aes(ymin=conf.low, ymax=conf.high), size=1)+
  geom_point(shape=15, size=4, color="white")+ geom_point(shape=15)+
  scale_y_continuous(limits=c(NA,0))+
  labs(title="Model results", subtitle="Mirroring tufte boxplot aesthetics, see ggthemes::geom_tufteboxplot()")+
  ggthemes::theme_tufte()

#............................................
# Write model results out ####
#............................................

write.table(model_results, "clipboard", sep="\t", row.names = F)
# or write csv and shell.exec
write.csv(model_results, "births_table2.csv", row.names = F)
# shell.exec("births_table2.csv")

#............................................
# RR/OR models and LRT demo ####
#............................................

# (HW4.3.Q11) RR and OR models
m1_rr = glm(data=births, preterm_f ~ pnc5_f, family=binomial(link="log")) #RR model
exp(coef(m1_rr))
m1_or = glm(data=births, preterm_f ~ pnc5_f, family=binomial(link="logit")) #OR model
exp(coef(m1_or))


# Model comparison HW4.Q11
model_data = na.omit(model_data) # also see complete.cases() for T/F vector. Nice for model comparisons where nesting is required.
m_crude_rd = glm(data=model_data, preterm_f ~ pnc5_f, family=binomial(link="identity"))
m_plussmoke_rd = glm(data=model_data, preterm_f ~ pnc5_f + smoker_f, family=binomial(link="identity"))
anova(m_crude_rd, m_plussmoke_rd, test = "LRT") #Better to use bias-variance trade-off process. See EPID 718.

m_plusmage_rd = glm(data=model_data, preterm_f ~ pnc5_f + smoker_f + mage, family=binomial(link="identity"))
anova(m_plusmage_rd, m_plussmoke_rd, test = "LRT") #Better to use bias-variance trade-off process. See EPID 718.

m_plusmagesq_rd = glm(data=births, preterm_f ~ pnc5_f + smoker_f + mage + mage_sq, family=binomial(link="identity"))
anova(m_plusmagesq_rd, m_plussmoke_rd, test = "LRT") #Better to use bias-variance trade-off process. See EPID 718.

# ......................................
# __End Homework 4 /  Start Homework 5 ####
# ......................................
